==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/en_GB.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "activated" : "activated",
    "updated" : "updated",
    "mounted" : "mounted",
    "deactivated" : "deactivated",
    "beforeCreate" : "beforeCreate",
    "created" : "created",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "destroyed",
    "beforeMount" : "beforeMount",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later",
    "Save backup codes" : "Save backup codes",
    "Print backup codes" : "Print backup codes",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup codes have been generated. {used} of {total} codes have been used.",
    "Regenerate backup codes" : "Regenerate backup codes",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "If you regenerate backup codes, you automatically invalidate old codes.",
    "Generate backup codes" : "Generate backup codes",
    "An error occurred while generating your backup codes" : "An error occurred while generating your backup codes",
    "Nextcloud backup codes" : "Nextcloud backup codes",
    "You created two-factor backup codes for your account" : "You created two-factor backup codes for your account",
    "Second-factor backup codes" : "Second-factor backup codes",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor.",
    "Backup code" : "Backup code",
    "Use backup code" : "Use backup code",
    "Two factor backup codes" : "Two factor backup codes",
    "A two-factor auth backup codes provider" : "A two-factor auth backup codes provider",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use one of the backup codes you saved when setting up two-factor authentication.",
    "Submit" : "Submit",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Backup codes have been generated. {{used}} of {{total}} codes have been used."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/en_GB.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later",
    "Save backup codes" : "Save backup codes",
    "Print backup codes" : "Print backup codes",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup codes have been generated. {used} of {total} codes have been used.",
    "Regenerate backup codes" : "Regenerate backup codes",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "If you regenerate backup codes, you automatically invalidate old codes.",
    "Generate backup codes" : "Generate backup codes",
    "An error occurred while generating your backup codes" : "An error occurred while generating your backup codes",
    "Nextcloud backup codes" : "Nextcloud backup codes",
    "You created two-factor backup codes for your account" : "You created two-factor backup codes for your account",
    "Second-factor backup codes" : "Second-factor backup codes",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor.",
    "Backup code" : "Backup code",
    "Use backup code" : "Use backup code",
    "Two factor backup codes" : "Two factor backup codes",
    "A two-factor auth backup codes provider" : "A two-factor auth backup codes provider",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Use one of the backup codes you saved when setting up two-factor authentication.",
    "Submit" : "Submit",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Backup codes have been generated. {{used}} of {{total}} codes have been used.",
    "activated" : "activated",
    "updated" : "updated",
    "mounted" : "mounted",
    "deactivated" : "deactivated",
    "beforeCreate" : "beforeCreate",
    "created" : "created",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "destroyed",
    "beforeMount" : "beforeMount"
},
"nplurals=2; plural=(n != 1);");
